@@ -5,17 +5,20 @@ from hera.cron_workflow import CronWorkflow
 from hera.cron_workflow_service import CronWorkflowService
 from hera.env import ConfigMapEnvSpec, EnvSpec, FieldEnvSpec, SecretEnvSpec
 from hera.env_from import ConfigMapEnvFromSpec, SecretEnvFromSpec
+from hera.host_alias import HostAlias
 from hera.image import ImagePullPolicy
 from hera.input import InputFrom
 from hera.operator import Operator
 from hera.resources import Resources
 from hera.retry import Retry
+from hera.retry_policy import RetryPolicy
 from hera.security_context import TaskSecurityContext, WorkflowSecurityContext
 from hera.task import Task
 from hera.template_ref import TemplateRef
 from hera.toleration import GPUToleration, Toleration
 from hera.ttl_strategy import TTLStrategy
-from hera.variable import VariableAsEnv
+from hera.variable import Variable, VariableAsEnv
+from hera.volume_claim_gc import VolumeClaimGCStrategy
 from hera.volumes import (
     AccessMode,
     ConfigMapVolume,
