@@ -9,6 +9,7 @@ from argo_workflows.models import (
 
 from hera.client import Client
 from hera.config import Config
+from hera.workflow_status import WorkflowStatus
 
 
 class WorkflowService:
@@ -43,10 +44,10 @@ class WorkflowService:
         api_client = Client(Config(host=self._host, verify_ssl=self._verify_ssl), token).api_client
         self.service = WorkflowServiceApi(api_client=api_client)
 
-    def submit(
+    def create(
         self, workflow: IoArgoprojWorkflowV1alpha1Workflow, namespace: str = 'default'
     ) -> IoArgoprojWorkflowV1alpha1Workflow:
-        """Submits the given workflow to the given namespace.
+        """Creates the given workflow to the given namespace.
 
         Parameters
         ----------
@@ -102,3 +103,36 @@ class WorkflowService:
             The workflow link.
         """
         return f'{self._host}/workflows/{self._namespace}/{name}?tab=workflow'
+
+    def get_workflow(self, name: str, namespace: str = 'default') -> IoArgoprojWorkflowV1alpha1Workflow:
+        """Fetches a workflow by the specified name and namespace combination.
+
+        Parameters
+        ----------
+        name: str
+            Name of the workflow.
+        namespace: str = 'default'
+            The namespace the workflow is running in.
+
+        Returns
+        -------
+        IoArgoprojWorkflowV1alpha1Workflow
+        """
+        return self.service.get_workflow(namespace, name, _check_return_type=False)
+
+    def get_workflow_status(self, name: str, namespace: str = 'default') -> WorkflowStatus:
+        """Returns the workflow status of the workflow identified by the specified name.
+
+        Parameters
+        ----------
+        name: str
+            Name of the workflow to fetch the status of.
+        namespace: str = 'default'
+            Namespace where the workflow is running/ran.
+
+        Returns
+        -------
+        WorkflowStatus
+        """
+        argo_status = self.get_workflow(name, namespace=namespace).status.get('phase')
+        return WorkflowStatus.from_argo_status(argo_status)
